pub async fn record_visit(
conn: &mut PgConnection,
course_module_completion_id: Uuid,
) -> ModelResult<Option<DateTime<Utc>>>Expand description
Records a visit and returns when the one before it was, if any.
pub async fn record_visit(
conn: &mut PgConnection,
course_module_completion_id: Uuid,
) -> ModelResult<Option<DateTime<Utc>>>Records a visit and returns when the one before it was, if any.